helpers

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetGlobalGitConfig

func GetGlobalGitConfig() (*config.Config, error)

GetGlobalGitConfig reads the global git configuration file and returns a config.Config object. Consumed internally by ReadUserConfig; also exported for direct use by autobump (github.com/rios0rios0/autobump).

func GetOptionFromConfig

func GetOptionFromConfig(cfg, globalCfg *config.Config, section string, option string) string

GetOptionFromConfig gets a Git option from local and global Git config. Consumed internally by ReadUserConfig; also exported for direct use by autobump (github.com/rios0rios0/autobump).

Types

This section is empty.

Jump to