Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetGlobalGitConfig ¶
GetGlobalGitConfig reads the global git configuration file and returns a config.Config object. Consumed internally by ReadUserConfig; also exported for direct use by autobump (github.com/rios0rios0/autobump).
func GetOptionFromConfig ¶
GetOptionFromConfig gets a Git option from local and global Git config. Consumed internally by ReadUserConfig; also exported for direct use by autobump (github.com/rios0rios0/autobump).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.